@@ -11,8 +11,8 @@ class logRoller:
     deletedLog = 'Deleted log: {}'
     readingLog = 'Reading log: {}'
     viewingLogs = 'Viewing logs...'
-    fileDownloading = 'Downloading ({})...'
-    fileDownloaded = 'Downloaded. Saved to downloads/{}'
+    fileDownloading = 'Downloading:{}'
+    fileDownloaded = 'Downloaded:downloads/{}'
     fileNotFound = 'File ({}) not found.'
     infoNotFound = 'Information ({} - {} - {}) not found.'
     repoNotFound = 'Repository ({}) not found.'
