@@ -846,31 +846,31 @@ def deleteLog():
         
 # Downloading release tarball
 def downloadTarball():
-    logging.info(logRoller.fileDownloading.format(f'octosuite.vBanner.versionTag.tar'))
-    sys.stdout.write(f"{SignVar.info} {logRoller.fileDownloading.format(octosuite.vBanner.versionTag.tar)}\n")
+    logging.info(logRoller.fileDownloading.format(f'octosuite.v{Banner.versionTag}.tar'))
+    sys.stdout.write(SignVar.info+' '+logRoller.fileDownloading.format(f'octosuite.v{Banner.versionTag}.tar')+'...\n')
     data = requests.get(f'{endpoint}/repos/rly0nheart/octosuite/tarball/{Banner.versionTag}')
     if data.status_code == 404:
     	logging.info(logRoller.tagNotFound.format(Banner.versionTag))
-    	sys.stdout.write(SignVar.negative+' '+logRoller.tagNotFound.format(Banner.versionTag))
+    	sys.stdout.write(f'{SignVar.negative} {logRoller.tagNotFound.format(Banner.versionTag)}\n')
     else:
         with open(f'downloads/octosuite.v{Banner.versionTag}.tar', 'wb') as file:
             file.write(data.content)
             file.close()
             
         logging.info(logRoller.fileDownloaded.format(f'octosuite.v{Banner.versionTag}.tar'))
-        sys.stdout.write(SignVar.positive+' '+logRoller.fileDownloaded.format(f'octosuite.v{Banner.versionTag}.tar')+'\n')
+        sys.stdout.write(SignVar.positive+' '+logRoller.fileDownloaded.format(f'octosuite.v{Banner.versionTag}.tar'))
 
 
 # Downloading release zipball
 def downloadZipball():
     logging.info(logRoller.fileDownloading.format(f'octosuite.v{Banner.versionTag}.zip'))
-    sys.stdout.write(f"{SignVar.info} {logRoller.fileDownloading.format(octosuite.vBanner.versionTag.zip)}\n")
+    sys.stdout.write(SignVar.info+' '+logRoller.fileDownloading.format(f'octosuite.v{Banner.versionTag}.zip')+'...\n')
     data = requests.get(f'{endpoint}/repos/rly0nheart/octosuite/zipball/{Banner.versionTag}')
     if data.status_code == 404:
     	logging.info(logRoller.tagNotFound.format(Banner.versionTag))
-    	sys.stdout.write(f"{SignVar.negative} {logRoller.tagNotFound.format(Banner.versionTag)}\n")
+    	sys.sdtout.write(f'{SignVar.negative} {logRoller.tagNotFound.format(Banner.versionTag)}\n')
     else:
-        with open(f'downloads/octosuite.v{Banner.versionTag}.tar', 'wb') as file:
+        with open(f'downloads/octosuite.v{Banner.versionTag}.zip', 'wb') as file:
             file.write(data.content)
             file.close()
             
@@ -937,15 +937,5 @@ OCTOSUITE.v{Banner.versionTag}
 
 What's changed?
 {'='*15}
-[✓] Fixed session terminating on error
-[✓] Added a csv logger: users will get to choose whether they wish to log output to a .csv file or not.
-[✓] For output that comes in bulk, users will get to specify how many result they wish to see
-[✓] Added a prompt for the 'exit' command
-[✓] Added 1 subcommand to the 'user' command: [user:follows] will now be used to check if user(A) follows user(B). [user:following] will now be used to return a list of user that the target is following
-[✓] Added 2 subcommands to the 'repo' command: [repo:issues] used for getting issues of a repository. [repo:releases] for getting releases of a repository
-[✓] Added 2 subcommands to the 'version' command: [version:check] will be used to check for new releases of octosuite. [version:info] will be used to see version information
-[✓] Added command 'source' (for developers): [source:tarball] for downloading a tarball of the octosuite source code. [source:zipball] for downloading a zipball of the octosuite source code.
-[✓] Will now be installing updates from pypi via 'pip install --upgrade octosuite' (As a result, all update commands have been deprecated)
-[✓] Properly formatted output in commits search results
-[✓] Perfomance improvements
+[fix] error in source commands (source:tarball, source:zipball) 
 ''')
